@@ -108,7 +108,8 @@ class Overlay:
         pygame.display.update()
         sleep(self.__delay)
         self.__window_rectangle = win32gui.GetWindowRect(self.__search_window_hwnd)
-        win32gui.MoveWindow(self.__overlay_hwnd, self.__window_rectangle[0] + 8, self.__window_rectangle[1] + 8, self.__window_rectangle[2] - 8, self.__window_rectangle[3] - 8, True)
+        print(self.__window_rectangle)
+        win32gui.MoveWindow(self.__overlay_hwnd, self.__window_rectangle[0], self.__window_rectangle[1], self.__window_rectangle[2], self.__window_rectangle[3], True)
         win32gui.ShowWindow(self.__overlay_hwnd, win32con.SW_SHOW)
         win32gui.SetWindowLong(self.__overlay_hwnd, win32con.GWL_EXSTYLE, win32gui.GetWindowLong(self.__overlay_hwnd, win32con.GWL_EXSTYLE) | win32con.WS_EX_TOOLWINDOW)
         self.__draw_list = []
